# Main file to run nlstruct
# Written by Clémence Sebe 
# October 2024

from nlstruct.recipes import train_qualified_ner
import os

# List of the models 
scibert_uncased = 'allenai/scibert_scivocab_cased'
bert_uncased =  'bert-base-uncased'

tab_models = [bert_uncased, scibert_uncased]

os.makedirs("models_train", exist_ok=True)

#Path of the data
# -"Ner_workflows_data/SoftCite_split"
# -"Ner_workflows_data/BioToFlow_split"
# -"Ner_workflows_data/Fusion_BioToFlow_SoftCite/with_just_conversion"
# -"Ner_workflows_data/Fusion_BioToFlow_SoftCite/with_silver"

path_data = "Ner_workflows_data/Fusion_BioToFlow_SoftCite/with_silver"

# -------------------------------------------------------------------------------------

# Vary random seeds
for graine in [1,8,22,42,100]:

    # Vary train/dev splits
    for i in range (1,6):

        for m in tab_models:
            print(f"---------------------- Iteration {i} - Model {m}")

            train = True
            if 'scibert_scivocab_uncased' in m:
                if f'scibert_iteration{i}_seed{graine}.pt' in os.listdir("models_train"):
                    train = False
            else:
                if f'bert_iteration{i}_seed{graine}.pt' in os.listdir("models_train"):
                    train = False

            if train:
                model = train_qualified_ner(
                    dataset={
                        "train": f"{path_data}/iteration_{i}/TRAIN",
                        "val"  : f"{path_data}/iteration_{i}/VAL", 
                        "test" : f"Ner_workflows_data/TEST_BioToFlow"
                    },
                    finetune_bert=False,
                    seed=graine,
                    bert_name=m,
                    fasttext_file="",
                    gpus=1, #0:cpu - 1:gpu
                    xp_name="my-xp",
                    return_model=True,
                    max_steps = 4000,
                    model_to_take_encoder="None",
                )

                if 'scibert_scivocab_uncased' in m:
                    model.save_pretrained(f'models_train/scibert_iteration{i}_seed{graine}.pt')
                else:
                    model.save_pretrained(f'models_train/bert_iteration{i}_seed{graine}.pt')

                os.system('rm checkpoints/*')
